@@ -1,6 +1,7 @@
-from .client import Client
+from .client import Client, SEND_METHOD
 from .server import Server, outstr
 
+SEND_METHOD = SEND_METHOD
 Server = Server
 Client = Client
 outstr = outstr
\ No newline at end of file
